@@ -5,11 +5,11 @@ use warnings;
 use lib 'lib';
 
 use Math::Symbolic qw/:all/;
-
 use Math::Symbolic::VectorCalculus qw/:all/;
 
-print join "\n",
-  map { $_->apply_derivatives()->simplify() } grad 'x*y+2*z*x-y^2';
+my @gradient = grad 'x*y+2*z*x-y^2';
+@gradient = map { $_->apply_derivatives()->simplify() } @gradient;
+print "$_\n" foreach @gradient;
 
 print "\n\n";
 
@@ -19,7 +19,9 @@ print $div->apply_derivatives()->simplify();
 
 print "\n\n";
 
-print join "\n", map { $_->apply_derivatives()->simplify() } rot @funcs;
+my @rot = rot @funcs;
+@rot = map { $_->apply_derivatives()->simplify() } @rot;
+print "$_\n" foreach @rot;
 
 print "\n\n";
 
